# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from af_licence_manager.models.ilm_exception import IlmException  # noqa: F401,E501

class LockException(IlmException):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'locked_object': 'str',
        'lock_owner': 'str',
        'lock_type': 'str'
    }
    if hasattr(IlmException, "swagger_types"):
        swagger_types.update(IlmException.swagger_types)

    attribute_map = {
        'locked_object': 'lockedObject',
        'lock_owner': 'lockOwner',
        'lock_type': 'lockType'
    }
    if hasattr(IlmException, "attribute_map"):
        attribute_map.update(IlmException.attribute_map)

    def __init__(self, locked_object=None, lock_owner=None, lock_type=None, *args, **kwargs):  # noqa: E501
        """LockException - a model defined in Swagger"""  # noqa: E501
        self._locked_object = None
        self._lock_owner = None
        self._lock_type = None
        if not(hasattr(self, "discriminator")) or not(self.discriminator):
            self.discriminator = None
        self.locked_object = locked_object
        if lock_owner is not None:
            self.lock_owner = lock_owner
        self.lock_type = lock_type
        IlmException.__init__(self, *args, **kwargs)

    @property
    def locked_object(self):
        """Gets the locked_object of this LockException.  # noqa: E501


        :return: The locked_object of this LockException.  # noqa: E501
        :rtype: str
        """
        return self._locked_object

    @locked_object.setter
    def locked_object(self, locked_object):
        """Sets the locked_object of this LockException.


        :param locked_object: The locked_object of this LockException.  # noqa: E501
        :type: str
        """
        if locked_object is None:
            raise ValueError("Invalid value for `locked_object`, must not be `None`")  # noqa: E501

        self._locked_object = locked_object

    @property
    def lock_owner(self):
        """Gets the lock_owner of this LockException.  # noqa: E501


        :return: The lock_owner of this LockException.  # noqa: E501
        :rtype: str
        """
        return self._lock_owner

    @lock_owner.setter
    def lock_owner(self, lock_owner):
        """Sets the lock_owner of this LockException.


        :param lock_owner: The lock_owner of this LockException.  # noqa: E501
        :type: str
        """

        self._lock_owner = lock_owner

    @property
    def lock_type(self):
        """Gets the lock_type of this LockException.  # noqa: E501


        :return: The lock_type of this LockException.  # noqa: E501
        :rtype: str
        """
        return self._lock_type

    @lock_type.setter
    def lock_type(self, lock_type):
        """Sets the lock_type of this LockException.


        :param lock_type: The lock_type of this LockException.  # noqa: E501
        :type: str
        """
        if lock_type is None:
            raise ValueError("Invalid value for `lock_type`, must not be `None`")  # noqa: E501

        self._lock_type = lock_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LockException, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LockException):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
