# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "af_licence_manager"
VERSION = "2.0.3"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="AristaFlow BPM LicenceManager/LicenceManager REST Client",
    author="AristaFlow GmbH",
    author_email="info@aristaflow.com",
    url="",
    keywords=["Swagger", "AristaFlowREST/LicenceManager"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="AristaFlow BPM REST Client library for connecting to the LicenceManager/LicenceManager endpoint. https://pypi.org/project/aristaflowpy/ provides APIs on top of the AristaFlow BPM REST endpoints for many use cases, so using aristaflowpy is recommended."
)
